from distutils.core import setup

setup(
    name='xlogger-lob',  # 对外模块的名字
    version='0.0.2',  # 版本号
    description='',  # 描述
    author='lobsterb',  # 作者
    author_email='57263573@qq.com',
    py_modules=['logger'],  # 要发布的模块
)
